@@ -42,5 +42,5 @@
 
 #define QT_FEATURE_spatialaudio 1
 
-#define QT_FEATURE_spatialaudio_quick3d -1
+#define QT_FEATURE_spatialaudio_quick3d 1
 
